@@ -59,44 +59,44 @@ linarpr <- function(Y, id=NULL, weight=NULL, Y_thres=NULL, wght_thres=NULL,
    # Y
    Y <- data.frame(Y)
    n <- nrow(Y)
-   if (ncol(Y) != 1) stop("'Y' must be vector or 1 column data.frame, matrix, data.table")
+   if (ncol(Y) != 1) stop("'Y' must be a vector or 1 column data.frame, matrix, data.table")
    Y <- Y[,1]
-   if(!is.numeric(Y)) stop("'Y' must be numerical")
-   if (any(is.na(Y))) stop("'Y' has unknown values")
+   if(!is.numeric(Y)) stop("'Y' must be numeric")
+   if (any(is.na(Y))) stop("'Y' has missing values")
 
    # weight
    weight <- data.frame(weight)
    if (nrow(weight) != n) stop("'weight' must be the same length as 'inc'")
-   if (ncol(weight) != 1) stop("'weight' must be vector or 1 column data.frame, matrix, data.table")
+   if (ncol(weight) != 1) stop("'weight' must be a vector or 1 column data.frame, matrix, data.table")
    weight <- weight[,1]
-   if (!is.numeric(weight)) stop("'weight' must be numerical")
-   if (any(is.na(weight))) stop("'weight' has unknown values")
+   if (!is.numeric(weight)) stop("'weight' must be numeric")
+   if (any(is.na(weight))) stop("'weight' has missing values")
 
    # Y_thres
    if (is.null(Y_thres)) Y_thres <- Y
    Y_thres <- data.frame(Y_thres)
    if (!is.null(Y_thres)) {
         if (nrow(Y_thres) != n) stop("'Y_thres' must be the same length as 'Y'")
-        if (ncol(Y_thres) != 1) stop("'Y_thres' must be vector or 1 column data.frame, matrix, data.table")
+        if (ncol(Y_thres) != 1) stop("'Y_thres' must be a vector or 1 column data.frame, matrix, data.table")
         Y_thres <- Y_thres[,1]
-        if(!is.numeric(Y_thres)) stop("'Y_thres' must be numerical")
-        if (any(is.na(Y_thres))) stop("'Y_thres' has unknown values") 
+        if(!is.numeric(Y_thres)) stop("'Y_thres' must be numeric")
+        if (any(is.na(Y_thres))) stop("'Y_thres' has missing values") 
      } 
 
    # wght_thres
    if (is.null(wght_thres)) wght_thres <- weight
    wght_thres <- data.frame(wght_thres)
    if (nrow(wght_thres) != n) stop("'wght_thres' must be the same length as 'Y'")
-   if (ncol(wght_thres) != 1) stop("'wght_thres' must be vector or 1 column data.frame, matrix, data.table")
+   if (ncol(wght_thres) != 1) stop("'wght_thres' must be a vector or 1 column data.frame, matrix, data.table")
    wght_thres <- wght_thres[,1]
-   if (!is.numeric(wght_thres)) stop("'wght_thres' must be numerical")
-   if (any(is.na(wght_thres))) stop("'wght_thres' has unknown values") 
+   if (!is.numeric(wght_thres)) stop("'wght_thres' must be numeric")
+   if (any(is.na(wght_thres))) stop("'wght_thres' has missing values") 
     
    # sort
    if (!is.null(sort)) {    
         sort <- data.frame(sort)
         if (length(sort) != n) stop("'sort' must have the same length as 'Y'")
-        if (ncol(sort) != 1) stop("'sort' must be vector or 1 column data.frame, matrix, data.table")
+        if (ncol(sort) != 1) stop("'sort' must be a vector or 1 column data.frame, matrix, data.table")
         sort <- sort[, 1]
    }
 
@@ -107,13 +107,14 @@ linarpr <- function(Y, id=NULL, weight=NULL, Y_thres=NULL, wght_thres=NULL,
                  stop("'period' are duplicate column names: ", 
                       paste(names(period)[duplicated(names(period))], collapse = ","))
        if (nrow(period) != n) stop("'period' must be the same length as 'Y'")
-       if(any(is.na(period))) stop("'period' has unknown values")
+       period[, (names(period)):=lapply(.SD, as.character)]
+       if(any(is.na(period))) stop("'period' has missing values")
    }   
    
    # id
    if (is.null(id)) id <- 1:n
    id <- data.table(id)
-   if (any(is.na(id))) stop("'id' has unknown values")
+   if (any(is.na(id))) stop("'id' has missing values")
    if (ncol(id) != 1) stop("'id' must be 1 column data.frame, matrix, data.table")
    if (nrow(id) != n) stop("'id' must be the same length as 'Y'")
    if (is.null(names(id))||(names(id)=="id")) setnames(id,names(id),"ID")
@@ -129,9 +130,10 @@ linarpr <- function(Y, id=NULL, weight=NULL, Y_thres=NULL, wght_thres=NULL,
              if (any(duplicated(names(Dom)))) 
                  stop("'Dom' are duplicate column names: ", 
                       paste(names(Dom)[duplicated(names(Dom))], collapse = ","))
-             if (is.null(names(Dom))) stop("'Dom' must be colnames")
+             if (is.null(names(Dom))) stop("'Dom' must have column names")
              if (nrow(Dom) != n) stop("'Dom' must be the same length as 'Y'")
              Dom[, (names(Dom)):=lapply(.SD, as.character)] 
+             if (any(is.na(Dom))) stop("'Dom' has missing values")
        }
 
     ## computations
