@@ -59,55 +59,55 @@ linarr <- function(Y, Y_den, id=NULL, age, pl085, month_at_work, weight=NULL,  s
    # Y
    Y <- data.frame(Y)
    n <- nrow(Y)
-   if (ncol(Y) != 1) stop("'Y' must be vector or 1 column data.frame, matrix, data.table")
+   if (ncol(Y) != 1) stop("'Y' must be a vector or 1 column data.frame, matrix, data.table")
    Y <- Y[,1]
-   if(!is.numeric(Y)) stop("'Y' must be numerical")
-   if (any(is.na(Y))) stop("'Y' has unknown values")
+   if(!is.numeric(Y)) stop("'Y' must be numeric")
+   if (any(is.na(Y))) stop("'Y' has missing values")
 
    Y_den <- data.frame(Y_den)
-   if (ncol(Y_den) != 1) stop("'Y_den' must be vector or 1 column data.frame, matrix, data.table")
+   if (ncol(Y_den) != 1) stop("'Y_den' must be a vector or 1 column data.frame, matrix, data.table")
    if (nrow(Y_den) != n) stop("'Y_den' must be the same length as 'Y'")
    Y_den <- Y_den[,1]
-   if(!is.numeric(Y_den)) stop("'Y_den' must be numerical")
-   if (any(is.na(Y_den))) stop("'Y_den' has unknown values")
+   if(!is.numeric(Y_den)) stop("'Y_den' must be numeric")
+   if (any(is.na(Y_den))) stop("'Y_den' has missing values")
 
    # weight
    weight <- data.frame(weight)
    if (nrow(weight) != n) stop("'weight' must be the same length as 'Y'")
-   if (ncol(weight) != 1) stop("'weight' must be vector or 1 column data.frame, matrix, data.table")
+   if (ncol(weight) != 1) stop("'weight' must be a vector or 1 column data.frame, matrix, data.table")
    weight <- weight[, 1]
-   if (!is.numeric(weight)) stop("'weight' must be numerical")
-   if (any(is.na(weight))) stop("'weight' has unknown values")
+   if (!is.numeric(weight)) stop("'weight' must be numeric")
+   if (any(is.na(weight))) stop("'weight' has missing values")
    
    # age
    age <- data.frame(age)
    if (nrow(age) != n) stop("'age' must be the same length as 'Y'")
-   if (ncol(age) != 1) stop("'age' must be vector or 1 column data.frame, matrix, data.table")
+   if (ncol(age) != 1) stop("'age' must be a vector or 1 column data.frame, matrix, data.table")
    age <- age[, 1]
-   if (!is.numeric(age)) stop("'age' must be numerical")
-   if (any(is.na(age))) stop("'age' has unknown values")
+   if (!is.numeric(age)) stop("'age' must be numeric")
+   if (any(is.na(age))) stop("'age' has missing values")
    
    # pl085
    pl085 <- data.frame(pl085)
    if (nrow(pl085) != n) stop("'pl085' must be the same length as 'Y'")
-   if (ncol(pl085) != 1) stop("'pl085' must be vector or 1 column data.frame, matrix, data.table")
+   if (ncol(pl085) != 1) stop("'pl085' must be a vector or 1 column data.frame, matrix, data.table")
    pl085 <- pl085[, 1]
-   if (!is.numeric(pl085)) stop("'pl085' must be numerical")
-   if (any(is.na(pl085))) stop("'pl085' has unknown values")
+   if (!is.numeric(pl085)) stop("'pl085' must be numeric")
+   if (any(is.na(pl085))) stop("'pl085' has missing values")
 
    # month_at_work
    month_at_work <- data.frame(month_at_work)
    if (nrow(month_at_work) != n) stop("'month_at_work' must be the same length as 'Y'")
-   if (ncol(month_at_work) != 1) stop("'month_at_work' must be vector or 1 column data.frame, matrix, data.table")
+   if (ncol(month_at_work) != 1) stop("'month_at_work' must be a vector or 1 column data.frame, matrix, data.table")
    month_at_work <- month_at_work[, 1]
-   if (!is.numeric(pl085)) stop("'month_at_work' must be numerical")
-   if (any(is.na(pl085))) stop("'month_at_work' has unknown values")
+   if (!is.numeric(pl085)) stop("'month_at_work' must be numeric")
+   if (any(is.na(pl085))) stop("'month_at_work' has missing values")
 
    # sort
    if (!is.null(sort)) {    
         sort <- data.frame(sort)
         if (length(sort) != n) stop("'sort' must have the same length as 'Y'")
-        if (ncol(sort) != 1) stop("'sort' must be vector or 1 column data.frame, matrix, data.table")
+        if (ncol(sort) != 1) stop("'sort' must be a vector or 1 column data.frame, matrix, data.table")
         sort <- sort[, 1]
    }
 
@@ -118,13 +118,14 @@ linarr <- function(Y, Y_den, id=NULL, age, pl085, month_at_work, weight=NULL,  s
                  stop("'period' are duplicate column names: ", 
                       paste(names(period)[duplicated(names(period))], collapse = ","))
        if (nrow(period) != n) stop("'period' must be the same length as 'Y'")
-       if(any(is.na(period))) stop("'period' has unknown values")
+       period[, (names(period)):=lapply(.SD, as.character)]
+       if(any(is.na(period))) stop("'period' has missing values")
    }   
    
    # id
    if (is.null(id)) id <- 1:n
    id <- data.table(id)
-   if (any(is.na(id))) stop("'id' has unknown values")
+   if (any(is.na(id))) stop("'id' has missing values")
    if (ncol(id) != 1) stop("'id' must be 1 column data.frame, matrix, data.table")
    if (nrow(id) != n) stop("'id' must be the same length as 'Y'")
    if (is.null(names(id))||(names(id)=="id")) setnames(id,names(id),"ID")
@@ -143,6 +144,7 @@ linarr <- function(Y, Y_den, id=NULL, age, pl085, month_at_work, weight=NULL,  s
              if (is.null(names(Dom))) stop("'Dom' must be colnames")
              if (nrow(Dom) != n) stop("'Dom' must be the same length as 'Y'")
              Dom[, (names(Dom)):=lapply(.SD, as.character)]
+             if (any(is.na(Dom))) stop("'Dom' has missing values")
        }
 
     ## computations
