@@ -52,25 +52,25 @@ linpoormed <- function(Y, id=NULL, weight=NULL, sort=NULL, Dom=NULL,
    # Y
    Y <- data.frame(Y)
    n <- nrow(Y)
-   if (ncol(Y) != 1) stop("'Y' must be vector or 1 column data.frame, matrix, data.table")
+   if (ncol(Y) != 1) stop("'Y' must be a vector or 1 column data.frame, matrix, data.table")
    Y <- Y[,1]
    if (!is.numeric(Y)) stop("'Y' must be a numeric vector")
-   if (any(is.na(Y))) stop("'Y' has unknown values")
+   if (any(is.na(Y))) stop("'Y' has missing values")
  
    # weight
    weight <- data.frame(weight)
    if (is.null(weight)) weight <- data.frame(rep.int(1, n))
    if (nrow(weight) != n) stop("'weight' must be the same length as 'Y'")
-   if (ncol(weight) != 1) stop("'weight' must be vector or 1 column data.frame, matrix, data.table")
+   if (ncol(weight) != 1) stop("'weight' must be a vector or 1 column data.frame, matrix, data.table")
    weight <- weight[,1]
-   if (!is.numeric(weight)) stop("'weight' must be numerical")
-   if (any(is.na(weight))) stop("'weight' has unknown values")
+   if (!is.numeric(weight)) stop("'weight' must be numeric")
+   if (any(is.na(weight))) stop("'weight' has missing values")
 
    # sort
    if (!is.null(sort)) {
         sort <- data.frame(sort)
         if (length(sort) != n) stop("'sort' must have the same length as 'Y'")
-        if (ncol(sort) != 1) stop("'sort' must be vector or 1 column data.frame, matrix, data.table")
+        if (ncol(sort) != 1) stop("'sort' must be a vector or 1 column data.frame, matrix, data.table")
         sort <- sort[, 1]
    }
 
@@ -81,7 +81,8 @@ linpoormed <- function(Y, id=NULL, weight=NULL, sort=NULL, Dom=NULL,
                  stop("'period' are duplicate column names: ", 
                       paste(names(period)[duplicated(names(period))], collapse = ","))
        if (nrow(period) != n) stop("'period' must be the same length as 'Y'")
-       if(any(is.na(period))) stop("'period' has unknown values")
+       period[, (names(period)):=lapply(.SD, as.character)]
+       if(any(is.na(period))) stop("'period' has missing values")
        }
    
    # id
@@ -103,9 +104,10 @@ linpoormed <- function(Y, id=NULL, weight=NULL, sort=NULL, Dom=NULL,
              if (any(duplicated(names(Dom)))) 
                  stop("'Dom' are duplicate column names: ", 
                       paste(names(Dom)[duplicated(names(Dom))], collapse = ","))
-             if (is.null(names(Dom))) stop("'Dom' must be colnames")
+             if (is.null(names(Dom))) stop("'Dom' must have column names")
              if (nrow(Dom) != n) stop("'Dom' must be the same length as 'Y'")
              Dom[, (names(Dom)):=lapply(.SD, as.character)]
+             if (any(is.na(Dom))) stop("'Dom' has missing values")
       }
  
     ## computations
