@@ -10,8 +10,8 @@ vardchangannual <- function(Y, H, PSU, w_final, id,
  
   ### Checking
 
-  if (length(percentratio) != 1 | !any(is.numeric(percentratio) | percentratio > 0)) stop("'percentratio' must be the positive numeric value")
-  if (length(use.estVar) != 1 | !any(is.logical(use.estVar))) stop("'use.estVar' must be the logical value")
+  if (length(percentratio) != 1 | !any(is.numeric(percentratio) | percentratio > 0)) stop("'percentratio' must be a positive numeric value")
+  if (length(use.estVar) != 1 | !any(is.logical(use.estVar))) stop("'use.estVar' must be logical")
   if(length(confidence) != 1 | any(!is.numeric(confidence) |  confidence < 0 | confidence > 1)) {
           stop("'confidence' must be a numeric value in [0,1]")  }
 
@@ -61,55 +61,55 @@ vardchangannual <- function(Y, H, PSU, w_final, id,
   Y <- data.table(Y, check.names=TRUE)
   n <- nrow(Y)
   m <- ncol(Y)
-  if (!all(sapply(Y, is.numeric))) stop("'Y' must be numerical")
-  if (any(is.na(Y))) stop("'Y' has unknown values")
-  if (is.null(names(Y))) stop("'Y' must be colnames")
+  if (!all(sapply(Y, is.numeric))) stop("'Y' must be numeric")
+  if (any(is.na(Y))) stop("'Y' has missing values")
+  if (is.null(names(Y))) stop("'Y' must have column names")
   
   # H
   H <- data.table(H)
   if (nrow(H) != n) stop("'H' length must be equal with 'Y' row count")
   if (ncol(H) != 1) stop("'H' must be 1 column data.frame, matrix, data.table")
-  if (any(is.na(H))) stop("'H' has unknown values")
-  if (is.null(names(H))) stop("'H' must be colnames")
+  if (any(is.na(H))) stop("'H' has missing values")
+  if (is.null(names(H))) stop("'H' must have column names")
   
   # id
   id <- data.table(id)
-  if (any(is.na(id))) stop("'id' has unknown values")
+  if (any(is.na(id))) stop("'id' has missing values")
   if (nrow(id) != n) stop("'id' length must be equal with 'Y' row count")
   if (ncol(id) != 1) stop("'id' must be 1 column data.frame, matrix, data.table")
   if (is.null(names(id))||(names(id)=="id")) setnames(id, names(id), "ID")
 
   # PSU
   PSU <- data.table(PSU)
-  if (any(is.na(PSU))) stop("'PSU' has unknown values")
+  if (any(is.na(PSU))) stop("'PSU' has missing values")
   if (nrow(PSU) != n) stop("'PSU' length must be equal with 'Y' row count")
   if (ncol(PSU) != 1) stop("'PSU' has more than 1 column")
   
   # w_final
   w_final <- data.frame(w_final)
   if (nrow(w_final) != n) stop("'w_final' must be equal with 'Y' row count")
-  if (ncol(w_final) != 1) stop("'w_final' must be vector or 1 column data.frame, matrix, data.table")
+  if (ncol(w_final) != 1) stop("'w_final' must be a vector or 1 column data.frame, matrix, data.table")
   w_final <- w_final[,1]
-  if (!is.numeric(w_final)) stop("'w_final' must be numerical")
-  if (any(is.na(w_final))) stop("'w_final' has unknown values") 
+  if (!is.numeric(w_final)) stop("'w_final' must be numeric")
+  if (any(is.na(w_final))) stop("'w_final' has missing values") 
   
   # country
   country <- data.table(country)
-  if (any(is.na(country))) stop("'country' has unknown values")
+  if (any(is.na(country))) stop("'country' has missing values")
   if (nrow(country) != n) stop("'country' length must be equal with 'Y' row count")
   if (ncol(country) != 1) stop("'country' must be 1 column")
   if (!is.character(country[[names(country)]])) stop("'country' must be character")
 
   # years
   years <- data.table(years, check.names=TRUE)
-  if (any(is.na(years))) stop("'years' has unknown values")
+  if (any(is.na(years))) stop("'years' has missing values")
   if (nrow(years) != n) stop("'years' length must be equal with 'Y' row count")
   if (ncol(years) != 1) stop("'years' must be 1 column")
   yearm <- names(years)
 
   # subperiods
   subperiods <- data.table(subperiods, check.names=TRUE)
-  if (any(is.na(subperiods))) stop("'subperiods' has unknown values")
+  if (any(is.na(subperiods))) stop("'subperiods' has missing values")
   if (nrow(subperiods) != n) stop("'subperiods' length must be equal with 'Y' row count")
   if (ncol(subperiods) != 1) stop("'subperiods' must be 1 column")
   subn <- data.table(years, subperiods)
@@ -123,9 +123,9 @@ vardchangannual <- function(Y, H, PSU, w_final, id,
            stop("'Dom' are duplicate column names: ", 
                  paste(names(Dom)[duplicated(names(Dom))], collapse = ","))
     if (nrow(Dom) != n) stop("'Dom' and 'Y' must be equal row count")
-    if (any(is.na(Dom))) stop("'Dom' has unknown values")
-    if (is.null(names(Dom))) stop("'Dom' must be colnames")
+    if (is.null(names(Dom))) stop("'Dom' must have column names")
     Dom[, (names(Dom)):=lapply(.SD, as.character)]
+    if (any(is.na(Dom))) stop("'Dom' has missing values")
   }
   
   namesZ <- NULL
@@ -133,8 +133,8 @@ vardchangannual <- function(Y, H, PSU, w_final, id,
     Z <- data.table(Z, check.names=TRUE)
     if (nrow(Z) != n) stop("'Z' and 'Y' must be equal row count")
     if (ncol(Z) != m) stop("'Z' and 'Y' must be equal column count")
-    if (any(is.na(Z))) stop("'Z' has unknown values")
-    if (is.null(names(Z))) stop("'Z' must be colnames")
+    if (any(is.na(Z))) stop("'Z' has missing values")
+    if (is.null(names(Z))) stop("'Z' must have column names")
     namesZ <- names(Z)
   }
  
@@ -142,7 +142,7 @@ vardchangannual <- function(Y, H, PSU, w_final, id,
    year1 <- data.table(year1, check.names=TRUE)
    if (ncol(year1) != 1) stop("'year1' must be 1 column")
    setnames(year1, names(year1), names(years))
-   if (any(is.na(year1))) stop("'year1' has unknown values")
+   if (any(is.na(year1))) stop("'year1' has missing values")
    yearss <- copy(years)
    yearss[, yearss:=1]
    if (any(is.na(merge(year1, yearss, all.x=TRUE,
@@ -153,7 +153,7 @@ vardchangannual <- function(Y, H, PSU, w_final, id,
    year2 <- data.table(year2, check.names=TRUE)
    if (ncol(year2) != 1) stop("'year2' must be 1 column")
    setnames(year2, names(year2), names(years))
-   if (any(is.na(year2))) stop("'year2' has unknown values")
+   if (any(is.na(year2))) stop("'year2' has missing values")
    if (any(is.na(merge(year2, yearss, all.x=TRUE,
                        by=names(years), allow.cartesian=TRUE))))
                        stop("'year2' row must be exist in 'years'")
